@@ -1,19 +1,10 @@
-/***************************************************************************
-                          FilterPMail.h  -  Pegasus-Mail import
-                             -------------------
-    begin                : Sat Jan 6 2001
-    copyright            : (C) 2001 by Holger Schurig
-    email                : holgerschurig@gmx.de
- ***************************************************************************/
+/*
+  filterpmail.h  -  Pegasus-Mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2001 Holger Schurig <holgerschurig@gmx.de>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef MAILIMPORTER_FILTER_PMAIL_H
 #define MAILIMPORTER_FILTER_PMAIL_H
@@ -22,12 +13,16 @@
 
 #include "filters.h"
 #include "mailimporter_utils.h"
-namespace MailImporter {
+namespace MailImporter
+{
+/**
+ * @brief The FilterPMail class
+ */
 class MAILIMPORTER_EXPORT FilterPMail : public Filter
 {
 public:
     FilterPMail();
-    ~FilterPMail();
+    ~FilterPMail() override;
 
     void import() override;
     void importMails(const QString &chosenDir);
@@ -62,12 +57,12 @@ private:
     QList<FolderStructure> folderMatrix;
     typedef QList<FolderStructure>::Iterator FolderStructureIterator;
 
-    bool folderParsed;
+    bool folderParsed = false;
 
     /** which file (of totalFiles) is now in the work? */
-    int currentFile;
+    int currentFile = 0;
     /** total number of files that get imported */
-    int totalFiles;
+    int totalFiles = 0;
 };
 }
 #endif
