@@ -1,28 +1,21 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef IMPORTMAILSWIDGET_H
 #define IMPORTMAILSWIDGET_H
 
-#include <QWidget>
 #include "mailimporter_export.h"
+#include <QWidget>
 class QListWidgetItem;
 namespace MailImporter
 {
 class ImportMailsWidgetPrivate;
+/**
+ * @brief The ImportMailsWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MAILIMPORTER_EXPORT ImportMailsWidget : public QWidget
 {
     Q_OBJECT
